## 0.1.11 (2022-04-27)

Drop Python 2 support from click-spinner (#7710)

## 0.1.10 (2022-02-03)

Improve `__enter__` & constructor methods (#7114)

## 0.1.9 (2022-01-08)

Use lowercase `type` everywhere (#6853)

## 0.1.7 (2021-12-17)

Always import Protocol from typing in stubs (#6617)

## 0.1.6 (2021-10-12)

Add star to all non-0.1 versions (#6146)

